<?xml version="1.0" encoding="utf-8"?>
<!DOCTYPE TS>
<TS version="2.1" language="de_DE">
<context>
    <name>Apollonius</name>
    <message>
        <location filename="../Apollonius.js" line="+1769"/>
        <source>Invalid radius</source>
        <translation>Ungültiger Radius</translation>
    </message>
    <message>
        <location line="+51"/>
        <source>No solution</source>
        <translation>Keine Lösung</translation>
    </message>
</context>
<context>
    <name>DefaultAction</name>
    <message>
        <location filename="../DefaultAction.js" line="+89"/>
        <source>Select entity or region</source>
        <translation>Element oder Bereich selektieren</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Move entity or reference</source>
        <translation>Element oder Referenzpunkt verschieben</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Set second corner</source>
        <translation>Zweiter Eckpunkt setzen</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Specify target point of reference point</source>
        <translation>Zielpunkt des Referenzpunktes angeben</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Specify target point of selection</source>
        <translation>Zielpunkt der Selektion angeben</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Move entity to desired location</source>
        <translation>Objekt verschieben</translation>
    </message>
    <message>
        <location line="+376"/>
        <source>Move Reference Point</source>
        <translation>Referenzpunkt verschieben</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Selection</source>
        <translation>Selektion verschieben</translation>
    </message>
    <message>
        <location line="+24"/>
        <source>Move Entity</source>
        <translation>Objekt verschieben</translation>
    </message>
    <message>
        <location line="+127"/>
        <source>Editing block &apos;%1&apos;&lt;br&gt;Choose &lt;i&gt;Block &gt; Return to Main Drawing&lt;/i&gt; when done</source>
        <translation>Block &apos;%1&apos; bearbeiten&lt;br&gt;Wählen Sie &lt;i&gt;Block &gt; Zurück zur Hauptzeichnung&lt;/i&gt;, um zur Hauptzeichnung zurückzukehren</translation>
    </message>
</context>
<context>
    <name>EAction</name>
    <message>
        <location filename="../EAction.js" line="+64"/>
        <source>Back</source>
        <translation>Zurück</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+2075"/>
        <source>Cancel</source>
        <translation>Abbrechen</translation>
    </message>
    <message>
        <location line="-1802"/>
        <location line="+136"/>
        <source>Active Tool:</source>
        <translation>Aktives Werkzeug:</translation>
    </message>
    <message>
        <source>Active Tool: %1</source>
        <translation type="obsolete">Aktives Werkzeug: %1</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>None</source>
        <translation>Kein</translation>
    </message>
    <message>
        <location line="+662"/>
        <source>Options</source>
        <translation>Optionen</translation>
    </message>
    <message>
        <source>Block Options</source>
        <translation type="vanished">Blockoptionen</translation>
    </message>
    <message>
        <location line="+28"/>
        <source>Main Tools</source>
        <translation>Hauptwerkzeuge</translation>
    </message>
    <message>
        <location line="+25"/>
        <source>CAD Tools</source>
        <translation>CAD Werkzeuge</translation>
    </message>
    <message>
        <location line="+710"/>
        <source>Entity is on a locked layer.</source>
        <translation>Element ist auf gesperrtem Layer.</translation>
    </message>
    <message>
        <location line="+232"/>
        <source>Length:</source>
        <translation>Länge:</translation>
    </message>
    <message>
        <location line="+40"/>
        <source>Entity is not a block reference.</source>
        <translation>Element ist keine Block Referenz.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line or arc.</source>
        <translation>Element ist keine Linie und kein Bogen.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or polyline.</source>
        <translation>Element ist keine Linie, kein Bogen und keine Polylinie.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line.</source>
        <translation>Element ist keine Linie.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc or circle.</source>
        <translation>Element ist kein Bogen und kein Kreis.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc or circle.</source>
        <translation>Element ist keine Linie und kein Bogen oder Kreis.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not an arc, circle or ellipse.</source>
        <translation>Element ist kein Bogen oder Kreis und keine Ellipse.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle or ellipse.</source>
        <translation>Element ist keine Linie, kein Bogen oder Kreis und keine Ellipse.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or polyline.</source>
        <translation>Element ist keine Linie, kein Bogen oder Kreis, keine Ellipse und keine Polylinie.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse or spline.</source>
        <translation>Element ist keine Linie, kein Bogen oder Kreis, keine Ellipse und keine Spline.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a line, arc, circle, ellipse, spline or polyline.</source>
        <translation>Element ist keine Linie, kein Bogen oder Kreis und keine Ellipse, Spline oder Polylinie.</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Entity is not a polyline.</source>
        <translation>Element ist keine Polylinie.</translation>
    </message>
</context>
<context>
    <name>ShapeAlgorithms</name>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric circle(s).</source>
        <translation type="vanished">Radius kleiner als 0.0 nach %1 konzentrischen Kreis(en).</translation>
    </message>
    <message>
        <source>Radius dropped below 0.0 after %1 concentric arc(s).</source>
        <translation type="vanished">Radius kleiner als 0.0 nach %1 konzentrischen Kreisbögen.</translation>
    </message>
    <message>
        <location filename="../ShapeAlgorithms.js" line="+1420"/>
        <source>No circle possible.</source>
        <translation>Kein Kreis möglich.</translation>
    </message>
    <message>
        <location line="+29"/>
        <source>No arc possible.</source>
        <translation>Kein Bogen möglich.</translation>
    </message>
    <message>
        <location line="+19"/>
        <source>Invalid number of segments: %1.</source>
        <translation>Ungültige Anzahl Segmente: %1.</translation>
    </message>
    <message>
        <location line="+6"/>
        <source>Invalid ellipse major / minor: %1 / %2.</source>
        <translation>Ungültiges Verhältnis von Major Radius zu Minor Radius: %1 / %2.</translation>
    </message>
    <message>
        <source>At least two points are identical</source>
        <translation type="obsolete">Mindestens zwei Punkte sind identisch</translation>
    </message>
    <message>
        <location line="-61"/>
        <location line="+29"/>
        <source>At least two points are identical.</source>
        <translation>Mindestens zwei Punkte sind identisch.</translation>
    </message>
</context>
<context>
    <name>WidgetFactory</name>
    <message>
        <location filename="../WidgetFactory.js" line="+1003"/>
        <source>Restore defaults</source>
        <translation>Standardwerte wieder herstellen</translation>
    </message>
    <message>
        <location line="+47"/>
        <source>Insert Symbol</source>
        <translation>Symbol einfügen</translation>
    </message>
    <message>
        <location line="+4"/>
        <source>Diameter</source>
        <translation>Durchmesser</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Arc</source>
        <translation>Bogen</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Degree</source>
        <translation>Grad</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Plus/Minus</source>
        <translation>Plus/Minus</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Almost equal to</source>
        <translation>Fast gleich</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Asymptotically equal to</source>
        <translation>Asymptotisch gleich</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Pi</source>
        <translation>Pi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square root</source>
        <translation>Quadratwurzel</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Phi</source>
        <translation>Phi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>phi</source>
        <translation>phi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Alt phi</source>
        <translation>Alt phi</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Ohm</source>
        <translation>Ohm</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>omega</source>
        <translation>omega</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Multiplication</source>
        <translation>Multiplikation</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Division</source>
        <translation>Division</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Square</source>
        <translation>Quadrat</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Delta</source>
        <translation>Delta</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Stacked text</source>
        <translation>Übereinander angeordneter Text</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Measured value</source>
        <translation>Gemessener Wert</translation>
    </message>
    <message>
        <location line="+116"/>
        <source>Left</source>
        <translation>Links</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Center</source>
        <translation>Zentrum</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Right</source>
        <translation>Rechts</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Aligned</source>
        <translation>Ausgerichtet</translation>
    </message>
    <message>
        <location line="+1"/>
        <location line="+7"/>
        <source>Middle</source>
        <translation>Mitte</translation>
    </message>
    <message>
        <location line="-6"/>
        <source>Fit</source>
        <translation>Anpassen</translation>
    </message>
    <message>
        <location line="+5"/>
        <source>Top</source>
        <translation>Oben</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Base</source>
        <translation>Basis</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Bottom</source>
        <translation>Unten</translation>
    </message>
    <message>
        <location line="+7"/>
        <location line="+4"/>
        <source>Clockwise</source>
        <translation>Uhrzeigersinn</translation>
    </message>
    <message>
        <location line="-3"/>
        <location line="+4"/>
        <source>Counterclockwise</source>
        <translation>Gegenuhrzeigersinn</translation>
    </message>
    <message>
        <location line="+7"/>
        <source>Preceding</source>
        <translation>Vorangehend</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>Above</source>
        <translation>Über</translation>
    </message>
    <message>
        <location line="+1"/>
        <source>None</source>
        <translation>Kein</translation>
    </message>
</context>
<context>
    <name>autostart</name>
    <message>
        <source>Loading translations...</source>
        <translation type="obsolete">Lade Übersetzungen...</translation>
    </message>
    <message>
        <source>Loading plugin translations...</source>
        <translation type="obsolete">Lade Plugin Übersetzungen...</translation>
    </message>
    <message>
        <source>Loading plugins...</source>
        <translation type="obsolete">Lade Plugins...</translation>
    </message>
    <message>
        <source>Initializing plugins...</source>
        <translation type="obsolete">Initialisiere Plugins...</translation>
    </message>
    <message>
        <source>Initializing plugins:</source>
        <translation type="obsolete">Initialisiere Plugins:</translation>
    </message>
    <message>
        <source>Post-initializing plugins...</source>
        <translation type="obsolete">Post-Initialisierung...</translation>
    </message>
    <message>
        <source>Post-Initialization...</source>
        <translation type="obsolete">Post-Initialisierung...</translation>
    </message>
    <message>
        <source>Searching for Plugins...</source>
        <translation type="obsolete">Suche Plugins...</translation>
    </message>
    <message>
        <location filename="../autostart.js" line="+327"/>
        <source>Loading add-on translations...</source>
        <translation>Lade Add-on Übersetzungen...</translation>
    </message>
    <message>
        <location line="+31"/>
        <source>Loading add-ons...</source>
        <translation>Lade Add-ons...</translation>
    </message>
    <message>
        <location line="+15"/>
        <source>Initializing add-ons...</source>
        <translation>Initialisiere Add-ons...</translation>
    </message>
    <message>
        <source>Post-initializing add-ons...</source>
        <translation type="vanished">Post-Initialisierung von Add-ons...</translation>
    </message>
    <message>
        <source>Loading add-on translations ...</source>
        <translation type="obsolete">Lade Add-on Übersetzungen ...</translation>
    </message>
    <message>
        <source>Loading add-ons ...</source>
        <translation type="obsolete">Lade Add-ons ...</translation>
    </message>
    <message>
        <source>Initializing add-ons ...</source>
        <translation type="obsolete">Initialisiere Add-ons ...</translation>
    </message>
    <message>
        <location line="+11"/>
        <source>Initializing add-ons:</source>
        <translation>Initialisiere Add-ons:</translation>
    </message>
    <message>
        <source>Post-initializing add-ons ...</source>
        <translation type="obsolete">Post-Initialisierung ...</translation>
    </message>
</context>
<context>
    <name>library</name>
    <message>
        <location filename="../library.js" line="+829"/>
        <source>Objects</source>
        <translation>Objekte</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Object</source>
        <translation>Objekt</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Unknown Objects</source>
        <translation>Unbekannte Objekte</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Object</source>
        <translation>Unbekanntes Objekt</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Blocks</source>
        <translation>Blöcke</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block</source>
        <translation>Block</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layers</source>
        <translation>Layer</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layer</source>
        <translation>Layer</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Layouts</source>
        <translation>Layouts</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Layout</source>
        <translation>Layout</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Linetypes</source>
        <translation>Linientypen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Linetype</source>
        <translation>Linientyp</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Views</source>
        <translation>Ansichten</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>View</source>
        <translation>Ansicht</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity</source>
        <translation>Objekt</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Entities</source>
        <translation>Objekte</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3dFaces</source>
        <translation>3dFaces</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3dFace</source>
        <translation>3dFace</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References</source>
        <translation>Block Referenzen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference</source>
        <translation>Block Referenz</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Block References and Attributes</source>
        <translation>Block Referenzen und Attribute</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Block Reference and Attributes</source>
        <translation>Block Referenz und Attribute</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arcs</source>
        <translation>Kreisbögen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Arc</source>
        <translation>Kreisbogen</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attributes</source>
        <translation>Attribute</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute</source>
        <translation>Attribut</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Attribute Definitions</source>
        <translation>Attributdefinitionen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Attribute Definition</source>
        <translation>Attributdefinition</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Circles</source>
        <translation>Kreise</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Circle</source>
        <translation>Kreis</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Dimensions</source>
        <translation>Bemassungen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Dimension</source>
        <translation>Bemassung</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Aligned Dimensions</source>
        <translation>Anliegende Bemassungen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Aligned Dimension</source>
        <translation>Anliegende Bemassung</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Angular Dimensions</source>
        <translation>Winkel Bemassungen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Angular Dimension</source>
        <translation>Winkel Bemassung</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>2 Line Angular Dimensions</source>
        <translation>2 Linien Winkelbemassungen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>2 Line Angular Dimension</source>
        <translation>2 Linien Winkelbemassung</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>3 Point Angular Dimensions</source>
        <translation>3 Punkte Winkelbemassungen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>3 Point Angular Dimension</source>
        <translation>3 Punkte Winkelbemassung</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Arc Dimension</source>
        <translation>Bogenbemassung</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Diametric Dimensions</source>
        <translation>Durchmesser Bemassungen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Diametric Dimension</source>
        <translation>Durchmesser Bemassung</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ordinate Dimensions</source>
        <translation>Koordinaten Bemassungen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ordinate Dimension</source>
        <translation>Koordinaten Bemassung</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rotated Dimensions</source>
        <translation>Gedrehte Bemassungen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Rotated Dimension</source>
        <translation>Gedrehte Bemassung</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Radial Dimensions</source>
        <translation>Radiale Bemassungen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Radial Dimension</source>
        <translation>Radiale Bemassung</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Ellipses</source>
        <translation>Ellipsen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ellipse</source>
        <translation>Ellipse</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Hatches</source>
        <translation>Schraffuren</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Hatch</source>
        <translation>Schraffur</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Images</source>
        <translation>Bilder</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Image</source>
        <translation>Bild</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Leaders</source>
        <translation>Führungslinien</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Leader</source>
        <translation>Führungslinie</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Lines</source>
        <translation>Linen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Line</source>
        <translation>Linie</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Infinite Lines</source>
        <translation>Unendliche Linien</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Infinite Line</source>
        <translation>Unendliche Linie</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Rays</source>
        <translation>Strahlen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Ray</source>
        <translation>Strahl</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Points</source>
        <translation>Punkte</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Point</source>
        <translation>Punkt</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Polylines</source>
        <translation>Polylinien</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Polyline</source>
        <translation>Polylinie</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Solids</source>
        <translation>Volumenkörper</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Solid</source>
        <translation>Volumenkörper</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Traces</source>
        <translation>Bänder</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Trace</source>
        <translation>Band</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Faces</source>
        <translation>Flächen</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Face</source>
        <translation>Fläche</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Splines</source>
        <translation>Splines</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Spline</source>
        <translation>Spline</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Text based</source>
        <translation>Textbasiert</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Texts</source>
        <translation>Texte</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Text</source>
        <translation>Text</translation>
    </message>
    <message>
        <location line="+2"/>
        <source>Viewports</source>
        <translation>Ansichtsfenster</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Viewport</source>
        <translation>Ansichtsfenster</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Unknown Entities</source>
        <translation>Unbekannte Elemente</translation>
    </message>
    <message>
        <location line="+0"/>
        <source>Unknown Entity</source>
        <translation>Unbekanntes Element</translation>
    </message>
</context>
<context>
    <name>simple_modify</name>
    <message>
        <location filename="../simple_modify.js" line="+301"/>
        <source>First entity cannot be trimmed.</source>
        <translation>Erstes Objekt kann nicht getrimmt werden.</translation>
    </message>
    <message>
        <location line="+3"/>
        <source>Entity cannot be trimmed.</source>
        <translation>Objekt kann nicht getrimmt werden.</translation>
    </message>
    <message>
        <location line="+10"/>
        <source>Second entity cannot be trimmed.</source>
        <translation>Zweites Objekt kann nicht getrimmt werden.</translation>
    </message>
</context>
</TS>
